@@ -18,25 +18,32 @@ class TestCommands(unittest.TestCase):
             self.employees_file_path = 'acme/data/employees.txt'
 
     def test_processing_wrong_arguments(self):
+        
         tests = [
             ['-casdfdsa'],
             ['data.bin'],
             ['-helpasd'],
         ]
+
         for test in tests:
+            
             out = io.StringIO()
             with cl.redirect_stdout(out):
                 processing(test)
             data = out.getvalue()
+
             err = 'Invalid argument.\nFor more information run: acme --help\n'
             self.assertEqual(data, err)
 
     def test_acme_command(self):
         test = [self.employees_file_path]
+        
+        # Get the console output
         out = io.StringIO()
         with cl.redirect_stdout(out):
             processing(test)
         data = out.getvalue()
+
         # Read sample salaries
         file_path = os.path.dirname(os.path.realpath(__file__))
         path: str = os.path.join(file_path, self.salary_file_path)
@@ -47,10 +54,32 @@ class TestCommands(unittest.TestCase):
 
     def test_acme_instructions(self):
         test = ['--help']
+
+        # Get the console output
         out = io.StringIO()
         with cl.redirect_stdout(out):
             processing(test)
-        data = re.sub(r'[\n\t\s]', '', out.getvalue())
+        output = re.sub(r'[\n\t\s]', '', out.getvalue())
+        
+        # Read instructions
         with open('tests/data/instructions.txt') as f:
-            ans = re.sub(r'[\n\t\s]', '', f.read())
-        self.assertEqual(data, ans)
+            instructions = re.sub(r'[\n\t\s]', '', f.read())
+
+        self.assertEqual(output, instructions)
+
+    def test_acme_demo_command(self):
+        test = ['--demo']
+
+        # Get the console output
+        out = io.StringIO()
+        with cl.redirect_stdout(out):
+            processing(test)
+        output = out.getvalue()
+
+        # Read sample employees data
+        file_path = os.path.dirname(os.path.realpath(__file__))
+        path: str = os.path.join(file_path, self.salary_file_path)
+        with open(path) as file:
+            content = file.read()
+
+        self.assertEqual(content, output)
\ No newline at end of file
